package com.mysql.jdbc;

import java.sql.ParameterMetaData;
import java.sql.SQLException;

/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/MysqlParameterMetadata.class */
public class MysqlParameterMetadata implements ParameterMetaData {
    boolean returnSimpleMetadata;
    ResultSetMetaData metadata;
    int parameterCount;

    /* JADX INFO: Access modifiers changed from: package-private */
    public MysqlParameterMetadata(Field[] fieldInfo, int parameterCount) {
        this.returnSimpleMetadata = false;
        this.metadata = null;
        this.parameterCount = 0;
        this.metadata = new ResultSetMetaData(fieldInfo, false);
        this.parameterCount = parameterCount;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public MysqlParameterMetadata(int count) {
        this.returnSimpleMetadata = false;
        this.metadata = null;
        this.parameterCount = 0;
        this.parameterCount = count;
        this.returnSimpleMetadata = true;
    }

    @Override // java.sql.ParameterMetaData
    public int getParameterCount() throws SQLException {
        return this.parameterCount;
    }

    @Override // java.sql.ParameterMetaData
    public int isNullable(int arg0) throws SQLException {
        checkAvailable();
        return this.metadata.isNullable(arg0);
    }

    private void checkAvailable() throws SQLException {
        if (this.metadata == null || this.metadata.fields == null) {
            throw SQLError.createSQLException("Parameter metadata not available for the given statement", SQLError.SQL_STATE_DRIVER_NOT_CAPABLE);
        }
    }

    @Override // java.sql.ParameterMetaData
    public boolean isSigned(int arg0) throws SQLException {
        if (this.returnSimpleMetadata) {
            checkBounds(arg0);
            return false;
        }
        checkAvailable();
        return this.metadata.isSigned(arg0);
    }

    @Override // java.sql.ParameterMetaData
    public int getPrecision(int arg0) throws SQLException {
        if (this.returnSimpleMetadata) {
            checkBounds(arg0);
            return 0;
        }
        checkAvailable();
        return this.metadata.getPrecision(arg0);
    }

    @Override // java.sql.ParameterMetaData
    public int getScale(int arg0) throws SQLException {
        if (this.returnSimpleMetadata) {
            checkBounds(arg0);
            return 0;
        }
        checkAvailable();
        return this.metadata.getScale(arg0);
    }

    @Override // java.sql.ParameterMetaData
    public int getParameterType(int arg0) throws SQLException {
        if (this.returnSimpleMetadata) {
            checkBounds(arg0);
            return 12;
        }
        checkAvailable();
        return this.metadata.getColumnType(arg0);
    }

    @Override // java.sql.ParameterMetaData
    public String getParameterTypeName(int arg0) throws SQLException {
        if (this.returnSimpleMetadata) {
            checkBounds(arg0);
            return "VARCHAR";
        }
        checkAvailable();
        return this.metadata.getColumnTypeName(arg0);
    }

    @Override // java.sql.ParameterMetaData
    public String getParameterClassName(int arg0) throws SQLException {
        if (this.returnSimpleMetadata) {
            checkBounds(arg0);
            return "java.lang.String";
        }
        checkAvailable();
        return this.metadata.getColumnClassName(arg0);
    }

    @Override // java.sql.ParameterMetaData
    public int getParameterMode(int arg0) throws SQLException {
        return 1;
    }

    private void checkBounds(int paramNumber) throws SQLException {
        if (paramNumber < 1) {
            throw SQLError.createSQLException(new StringBuffer().append("Parameter index of '").append(paramNumber).append("' is invalid.").toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
        if (paramNumber > this.parameterCount) {
            throw SQLError.createSQLException(new StringBuffer().append("Parameter index of '").append(paramNumber).append("' is greater than number of parameters, which is '").append(this.parameterCount).append("'.").toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }

    @Override // java.sql.Wrapper
    public boolean isWrapperFor(Class iface) throws SQLException {
        return iface.isInstance(this);
    }

    @Override // java.sql.Wrapper
    public Object unwrap(Class iface) throws SQLException {
        try {
            return Util.cast(iface, this);
        } catch (ClassCastException e) {
            throw SQLError.createSQLException(new StringBuffer().append("Unable to unwrap to ").append(iface.toString()).toString(), SQLError.SQL_STATE_ILLEGAL_ARGUMENT);
        }
    }
}
